summaryrefslogtreecommitdiffhomepage
path: root/Opcode/Ice/IceSegment.h
diff options
context:
space:
mode:
Diffstat (limited to 'Opcode/Ice/IceSegment.h')
-rw-r--r--Opcode/Ice/IceSegment.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/Opcode/Ice/IceSegment.h b/Opcode/Ice/IceSegment.h
index 3dc8314..e3ce8ab 100644
--- a/Opcode/Ice/IceSegment.h
+++ b/Opcode/Ice/IceSegment.h
@@ -18,19 +18,19 @@
//! Constructor
inline_ Segment() {}
//! Constructor
- inline_ Segment(const Point& p0, const Point& p1) : mP0(p0), mP1(p1) {}
+ inline_ Segment(const IcePoint& p0, const IcePoint& p1) : mP0(p0), mP1(p1) {}
//! Copy constructor
inline_ Segment(const Segment& seg) : mP0(seg.mP0), mP1(seg.mP1) {}
//! Destructor
inline_ ~Segment() {}
- inline_ const Point& GetOrigin() const { return mP0; }
- inline_ Point ComputeDirection() const { return mP1 - mP0; }
- inline_ void ComputeDirection(Point& dir) const { dir = mP1 - mP0; }
+ inline_ const IcePoint& GetOrigin() const { return mP0; }
+ inline_ IcePoint ComputeDirection() const { return mP1 - mP0; }
+ inline_ void ComputeDirection(IcePoint& dir) const { dir = mP1 - mP0; }
inline_ float ComputeLength() const { return mP1.Distance(mP0); }
inline_ float ComputeSquareLength() const { return mP1.SquareDistance(mP0); }
- inline_ void SetOriginDirection(const Point& origin, const Point& direction)
+ inline_ void SetOriginDirection(const IcePoint& origin, const IcePoint& direction)
{
mP0 = mP1 = origin;
mP1 += direction;
@@ -38,18 +38,18 @@
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/**
* Computes a point on the segment
* \param pt [out] point on segment
* \param t [in] point's parameter [t=0 => pt = mP0, t=1 => pt = mP1]
*/
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
- inline_ void ComputePoint(Point& pt, float t) const { pt = mP0 + t * (mP1 - mP0); }
+ inline_ void ComputePoint(IcePoint& pt, float t) const { pt = mP0 + t * (mP1 - mP0); }
- float SquareDistance(const Point& point, float* t=null) const;
- inline_ float Distance(const Point& point, float* t=null) const { return sqrtf(SquareDistance(point, t)); }
+ float SquareDistance(const IcePoint& IcePoint, float* t=null) const;
+ inline_ float Distance(const IcePoint& IcePoint, float* t=null) const { return sqrtf(SquareDistance(IcePoint, t)); }
- Point mP0; //!< Start of segment
- Point mP1; //!< End of segment
+ IcePoint mP0; //!< Start of segment
+ IcePoint mP1; //!< End of segment
};
#endif // __ICESEGMENT_H__
@@ -38,18 +38,18 @@
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/**
- * Computes a point on the segment
- * \param pt [out] point on segment
- * \param t [in] point's parameter [t=0 => pt = mP0, t=1 => pt = mP1]
+ * Computes a IcePoint on the segment
+ * \param pt [out] IcePoint on segment
+ * \param t [in] IcePoint's parameter [t=0 => pt = mP0, t=1 => pt = mP1]
*/
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////